summaryrefslogtreecommitdiff
path: root/boost/date_time/date_generators.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'boost/date_time/date_generators.hpp')
-rw-r--r--boost/date_time/date_generators.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/boost/date_time/date_generators.hpp b/boost/date_time/date_generators.hpp
index 274ce1f06a..67bfd5f077 100644
--- a/boost/date_time/date_generators.hpp
+++ b/boost/date_time/date_generators.hpp
@@ -25,7 +25,7 @@ namespace date_time {
//! Base class for all generators that take a year and produce a date.
/*! This class is a base class for polymorphic function objects that take
a year and produce a concrete date.
- @param date_type The type representing a date. This type must
+ @tparam date_type The type representing a date. This type must
export a calender_type which defines a year_type.
*/
template<class date_type>
@@ -307,7 +307,7 @@ namespace date_time {
/*! Useful generator functor for finding holidays and daylight savings
* Get the last day of the month and then calculate the difference
* to the last previous day.
* @param date_type A date class that exports day_of_week, month_type, etc.
* \ingroup date_alg
*/
template<class date_type>
@@ -307,7 +307,7 @@ namespace date_time {
* Get the last day of the month and then calculate the difference
* to the last previous day.
- * @param date_type A date class that exports day_of_week, month_type, etc.
+ * @tparam date_type A date class that exports day_of_week, month_type, etc.
* \ingroup date_alg
*/